geowatch.monkey.monkey\_albumentations module
=============================================

.. automodule:: geowatch.monkey.monkey_albumentations
   :members:
   :undoc-members:
   :show-inheritance:
